@@ -7,7 +7,7 @@ from scipy.integrate import ode
 import pyatmos as atm
 import mayavi as mya
 
-import util as ut
+from . import util as ut
 
 class Orbit:
     """
